@@ -44,8 +44,7 @@ class PdfExportOptions(ExportOptions):
     """
     swagger_types = {
         'default_regular_font': 'str',
-        'height': 'int',
-        'width': 'int',
+        'font_fallback_rules': 'list[FontFallbackRule]',
         'format': 'str',
         'text_compression': 'str',
         'embed_full_fonts': 'bool',
@@ -65,13 +64,12 @@ class PdfExportOptions(ExportOptions):
         'show_comments_by_no_author': 'bool',
         'image_transparent_color': 'str',
         'apply_image_transparent': 'bool',
-        'access_permissions': 'str'
+        'access_permissions': 'AccessPermissions'
     }
 
     attribute_map = {
         'default_regular_font': 'defaultRegularFont',
-        'height': 'height',
-        'width': 'width',
+        'font_fallback_rules': 'fontFallbackRules',
         'format': 'format',
         'text_compression': 'textCompression',
         'embed_full_fonts': 'embedFullFonts',
@@ -98,9 +96,9 @@ class PdfExportOptions(ExportOptions):
         'format': 'pdf',
     }
 
-    def __init__(self, default_regular_font=None, height=None, width=None, format='pdf', text_compression=None, embed_full_fonts=None, compliance=None, sufficient_resolution=None, jpeg_quality=None, draw_slides_frame=None, show_hidden_slides=None, save_metafiles_as_png=None, password=None, embed_true_type_fonts_for_ascii=None, additional_common_font_families=None, notes_position=None, comments_position=None, comments_area_width=None, comments_area_color=None, show_comments_by_no_author=None, image_transparent_color=None, apply_image_transparent=None, access_permissions=None):  # noqa: E501
+    def __init__(self, default_regular_font=None, font_fallback_rules=None, format='pdf', text_compression=None, embed_full_fonts=None, compliance=None, sufficient_resolution=None, jpeg_quality=None, draw_slides_frame=None, show_hidden_slides=None, save_metafiles_as_png=None, password=None, embed_true_type_fonts_for_ascii=None, additional_common_font_families=None, notes_position=None, comments_position=None, comments_area_width=None, comments_area_color=None, show_comments_by_no_author=None, image_transparent_color=None, apply_image_transparent=None, access_permissions=None):  # noqa: E501
         """PdfExportOptions - a model defined in Swagger"""  # noqa: E501
-        super(PdfExportOptions, self).__init__(default_regular_font, height, width, format)
+        super(PdfExportOptions, self).__init__(default_regular_font, font_fallback_rules, format)
 
         self._text_compression = None
         self._embed_full_fonts = None
@@ -629,7 +627,7 @@ class PdfExportOptions(ExportOptions):
         Access permissions that should be granted when the document is opened with user access.  Default is AccessPermissions.None.               # noqa: E501
 
         :return: The access_permissions of this PdfExportOptions.  # noqa: E501
-        :rtype: str
+        :rtype: AccessPermissions
         """
         return self._access_permissions
 
@@ -640,24 +638,8 @@ class PdfExportOptions(ExportOptions):
         Access permissions that should be granted when the document is opened with user access.  Default is AccessPermissions.None.               # noqa: E501
 
         :param access_permissions: The access_permissions of this PdfExportOptions.  # noqa: E501
-        :type: str
+        :type: AccessPermissions
         """
-        if access_permissions is not None:
-            allowed_values = ["None", "PrintDocument", "ModifyContent", "CopyTextAndGraphics", "AddOrModifyFields", "FillExistingFields", "ExtractTextAndGraphics", "AssembleDocument", "HighQualityPrint"]  # noqa: E501
-            if access_permissions.isdigit():
-                int_access_permissions = int(access_permissions)
-                if int_access_permissions < 0 or int_access_permissions >= len(allowed_values):
-                    raise ValueError(
-                        "Invalid value for `access_permissions` ({0}), must be one of {1}"  # noqa: E501
-                        .format(access_permissions, allowed_values)
-                    )
-                self._access_permissions = allowed_values[int_access_permissions]
-                return
-            if access_permissions not in allowed_values:
-                raise ValueError(
-                    "Invalid value for `access_permissions` ({0}), must be one of {1}"  # noqa: E501
-                    .format(access_permissions, allowed_values)
-                )
         self._access_permissions = access_permissions
 
     def to_dict(self):
