@@ -44,16 +44,14 @@ class PptxExportOptions(ExportOptions):
     """
     swagger_types = {
         'default_regular_font': 'str',
-        'height': 'int',
-        'width': 'int',
+        'font_fallback_rules': 'list[FontFallbackRule]',
         'format': 'str',
         'conformance': 'str'
     }
 
     attribute_map = {
         'default_regular_font': 'defaultRegularFont',
-        'height': 'height',
-        'width': 'width',
+        'font_fallback_rules': 'fontFallbackRules',
         'format': 'format',
         'conformance': 'conformance'
     }
@@ -62,9 +60,9 @@ class PptxExportOptions(ExportOptions):
         'format': 'pptx',
     }
 
-    def __init__(self, default_regular_font=None, height=None, width=None, format='pptx', conformance=None):  # noqa: E501
+    def __init__(self, default_regular_font=None, font_fallback_rules=None, format='pptx', conformance=None):  # noqa: E501
         """PptxExportOptions - a model defined in Swagger"""  # noqa: E501
-        super(PptxExportOptions, self).__init__(default_regular_font, height, width, format)
+        super(PptxExportOptions, self).__init__(default_regular_font, font_fallback_rules, format)
 
         self._conformance = None
         self.format = 'pptx'
@@ -93,7 +91,7 @@ class PptxExportOptions(ExportOptions):
         :type: str
         """
         if conformance is not None:
-            allowed_values = ["Ecma376_2006", "Iso29500_2008_Transitional", "Iso29500_2008_Strict"]  # noqa: E501
+            allowed_values = ["Ecma376", "Iso29500Transitional", "Iso29500Strict"]  # noqa: E501
             if conformance.isdigit():
                 int_conformance = int(conformance)
                 if int_conformance < 0 or int_conformance >= len(allowed_values):
